@@ -187,6 +187,29 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateAclRule(self, request):
+        """添加 ACL 规则
+
+        :param request: Request instance for CreateAclRule.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.CreateAclRuleRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.CreateAclRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAclRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAclRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateCdcCluster(self, request):
         """用于cdc的专用ckafka集群
 
@@ -279,6 +302,29 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateDatahubTopic(self, request):
+        """创建Datahub主题
+
+        :param request: Request instance for CreateDatahubTopic.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.CreateDatahubTopicRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.CreateDatahubTopicResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDatahubTopic", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDatahubTopicResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateInstancePost(self, request):
         """创建按量计费实例
 
@@ -762,6 +808,29 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAclRule(self, request):
+        """查询ACL规则列表
+
+        :param request: Request instance for DescribeAclRule.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeAclRuleRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeAclRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAclRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAclRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAppInfo(self, request):
         """查询用户列表
 
@@ -946,6 +1015,52 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDatahubTopic(self, request):
+        """获取Datahub主题属性
+
+        :param request: Request instance for DescribeDatahubTopic.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeDatahubTopicRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeDatahubTopicResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDatahubTopic", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDatahubTopicResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeDatahubTopics(self, request):
+        """查询DIP主题列表
+
+        :param request: Request instance for DescribeDatahubTopics.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeDatahubTopicsRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeDatahubTopicsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDatahubTopics", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDatahubTopicsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeGroup(self, request):
         """枚举消费分组(精简版)
 
@@ -1407,6 +1522,29 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyAclRule(self, request):
+        """修改AC策略，目前只支持预设规则的是否应用到新增topic这一项的修改
+
+        :param request: Request instance for ModifyAclRule.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.ModifyAclRuleRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.ModifyAclRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAclRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAclRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyConnectResource(self, request):
         """编辑Datahub连接源
 
