@@ -598,6 +598,93 @@ class DeployConfig(AbstractModel):
         
 
 
+class DescribeAccessLogConfigRequest(AbstractModel):
+    """DescribeAccessLogConfig请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: mesh名字
+        :type MeshId: str
+        """
+        self.MeshId = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeAccessLogConfigResponse(AbstractModel):
+    """DescribeAccessLogConfig返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param File: 访问日志输出路径。默认 /dev/stdout
+        :type File: str
+        :param Format: 访问日志的格式。
+        :type Format: str
+        :param Encoding: 访问日志输出编码，可取值为 "TEXT" 或 "JSON"，默认 TEXT"
+        :type Encoding: str
+        :param SelectedRange: 选中的范围
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SelectedRange: :class:`tencentcloud.tcm.v20210413.models.SelectedRange`
+        :param Template: 采用的模板，可取值为"istio" 或 "trace"，默认为"istio"
+        :type Template: str
+        :param CLS: 腾讯云日志服务相关参数
+        :type CLS: :class:`tencentcloud.tcm.v20210413.models.CLS`
+        :param Address: GRPC第三方服务器地址
+        :type Address: str
+        :param EnableServer: 是否启用GRPC第三方服务器
+        :type EnableServer: bool
+        :param EnableStdout: 是否启用标准输出
+        :type EnableStdout: bool
+        :param Enable: 是否启用访问日志采集
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Enable: bool
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.File = None
+        self.Format = None
+        self.Encoding = None
+        self.SelectedRange = None
+        self.Template = None
+        self.CLS = None
+        self.Address = None
+        self.EnableServer = None
+        self.EnableStdout = None
+        self.Enable = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.File = params.get("File")
+        self.Format = params.get("Format")
+        self.Encoding = params.get("Encoding")
+        if params.get("SelectedRange") is not None:
+            self.SelectedRange = SelectedRange()
+            self.SelectedRange._deserialize(params.get("SelectedRange"))
+        self.Template = params.get("Template")
+        if params.get("CLS") is not None:
+            self.CLS = CLS()
+            self.CLS._deserialize(params.get("CLS"))
+        self.Address = params.get("Address")
+        self.EnableServer = params.get("EnableServer")
+        self.EnableStdout = params.get("EnableStdout")
+        self.Enable = params.get("Enable")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeMeshListRequest(AbstractModel):
     """DescribeMeshList请求参数结构体
 
@@ -1225,6 +1312,53 @@ class LinkClusterListResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class LinkPrometheusRequest(AbstractModel):
+    """LinkPrometheus请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshID: 网格ID
+        :type MeshID: str
+        :param Prometheus: 配置
+        :type Prometheus: :class:`tencentcloud.tcm.v20210413.models.PrometheusConfig`
+        """
+        self.MeshID = None
+        self.Prometheus = None
+
+
+    def _deserialize(self, params):
+        self.MeshID = params.get("MeshID")
+        if params.get("Prometheus") is not None:
+            self.Prometheus = PrometheusConfig()
+            self.Prometheus._deserialize(params.get("Prometheus"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class LinkPrometheusResponse(AbstractModel):
+    """LinkPrometheus返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class LoadBalancer(AbstractModel):
     """负载均衡配置
 
@@ -1320,16 +1454,21 @@ class LoadBalancerStatus(AbstractModel):
         :type LoadBalancerName: str
         :param LoadBalancerVip: 负载均衡实例 VIP
         :type LoadBalancerVip: str
+        :param LoadBalancerHostname: 负载均衡实例 Hostname
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LoadBalancerHostname: str
         """
         self.LoadBalancerId = None
         self.LoadBalancerName = None
         self.LoadBalancerVip = None
+        self.LoadBalancerHostname = None
 
 
     def _deserialize(self, params):
         self.LoadBalancerId = params.get("LoadBalancerId")
         self.LoadBalancerName = params.get("LoadBalancerName")
         self.LoadBalancerVip = params.get("LoadBalancerVip")
+        self.LoadBalancerHostname = params.get("LoadBalancerHostname")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1592,6 +1731,87 @@ class MetricSpec(AbstractModel):
         
 
 
+class ModifyAccessLogConfigRequest(AbstractModel):
+    """ModifyAccessLogConfig请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: mesh ID
+        :type MeshId: str
+        :param SelectedRange: 选中的范围
+        :type SelectedRange: :class:`tencentcloud.tcm.v20210413.models.SelectedRange`
+        :param Template: 采用的模板，可选值：istio（默认）、trace、custom
+        :type Template: str
+        :param Enable: 是否启用
+        :type Enable: bool
+        :param CLS: 腾讯云日志服务相关参数
+        :type CLS: :class:`tencentcloud.tcm.v20210413.models.CLS`
+        :param Encoding: 编码格式，可选值：TEXT、JSON
+        :type Encoding: str
+        :param Format: 日志格式
+        :type Format: str
+        :param EnableStdout: 是否启用标准输出
+        :type EnableStdout: bool
+        :param EnableServer: 是否启动GRPC第三方服务器
+        :type EnableServer: bool
+        :param Address: GRPC第三方服务器地址
+        :type Address: str
+        """
+        self.MeshId = None
+        self.SelectedRange = None
+        self.Template = None
+        self.Enable = None
+        self.CLS = None
+        self.Encoding = None
+        self.Format = None
+        self.EnableStdout = None
+        self.EnableServer = None
+        self.Address = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        if params.get("SelectedRange") is not None:
+            self.SelectedRange = SelectedRange()
+            self.SelectedRange._deserialize(params.get("SelectedRange"))
+        self.Template = params.get("Template")
+        self.Enable = params.get("Enable")
+        if params.get("CLS") is not None:
+            self.CLS = CLS()
+            self.CLS._deserialize(params.get("CLS"))
+        self.Encoding = params.get("Encoding")
+        self.Format = params.get("Format")
+        self.EnableStdout = params.get("EnableStdout")
+        self.EnableServer = params.get("EnableServer")
+        self.Address = params.get("Address")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyAccessLogConfigResponse(AbstractModel):
+    """ModifyAccessLogConfig返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class ModifyMeshRequest(AbstractModel):
     """ModifyMesh请求参数结构体
 
@@ -1652,6 +1872,67 @@ class ModifyMeshResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ModifyTracingConfigRequest(AbstractModel):
+    """ModifyTracingConfig请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: mesh名字
+        :type MeshId: str
+        :param Enable: 是否启用调用跟踪
+        :type Enable: bool
+        :param APM: 腾讯云 APM 服务相关参数
+        :type APM: :class:`tencentcloud.tcm.v20210413.models.APM`
+        :param Sampling: 调用跟踪采样值
+        :type Sampling: float
+        :param Zipkin: 调用追踪Zipkin相关配置
+        :type Zipkin: :class:`tencentcloud.tcm.v20210413.models.TracingZipkin`
+        """
+        self.MeshId = None
+        self.Enable = None
+        self.APM = None
+        self.Sampling = None
+        self.Zipkin = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        self.Enable = params.get("Enable")
+        if params.get("APM") is not None:
+            self.APM = APM()
+            self.APM._deserialize(params.get("APM"))
+        self.Sampling = params.get("Sampling")
+        if params.get("Zipkin") is not None:
+            self.Zipkin = TracingZipkin()
+            self.Zipkin._deserialize(params.get("Zipkin"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyTracingConfigResponse(AbstractModel):
+    """ModifyTracingConfig返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class PodsMetricSource(AbstractModel):
     """PodsMetricSource 定义了如何根据特定指标进行扩缩容
 
@@ -2149,6 +2430,47 @@ class UnlinkClusterResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class UnlinkPrometheusRequest(AbstractModel):
+    """UnlinkPrometheus请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshID: 网格ID
+        :type MeshID: str
+        """
+        self.MeshID = None
+
+
+    def _deserialize(self, params):
+        self.MeshID = params.get("MeshID")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UnlinkPrometheusResponse(AbstractModel):
+    """UnlinkPrometheus返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class WorkloadConfig(AbstractModel):
     """工作负载配置
 
