@@ -717,7 +717,8 @@ class TrpClient(AbstractClient):
 
 
     def DescribeScanStats(self, request):
-        """查询某个批次被扫码的统计列表，没有被扫过的不会返回
+        """查询扫码的统计信息列表，支持按照商户ID，产品ID，批次ID，安心码筛选，筛选条件至少有一个
+        没有被扫过的不会返回
 
         :param request: Request instance for DescribeScanStats.
         :type request: :class:`tencentcloud.trp.v20210515.models.DescribeScanStatsRequest`
